tonalitytools.ScaleDegree
=========================

.. abjad-lineage:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree

.. autoclass:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.accidental
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.name
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.number
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.roman_numeral_string
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.storage_format
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.symbolic_string
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.title_string
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.apply_accidental
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.__le__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.ScaleDegree.ScaleDegree.ScaleDegree.__str__
   :noindex:
